<?php

namespace NoccyLabs\React\Http\Security;

class StaticUserManager implements UserManagerInterface
{
    private array $users = [];

    private array $userIdMap = [];

    public function __construct()
    {
        
    }

    public function addUser(UserInterface $user)
    {
        $this->users[$user->getUsername()] = $user;
        $this->userIdMap[$user->getId()] = $user->getUsername();
    }

    /**
     * {@inheritDoc}
     *
     * @param int $userId
     * @return UserInterface
     * @throws UserNotFoundException if the user can not be found
     * @throws InvalidCredentialsException if the credentials are invalid
     */
    public function getUser(int $userId): UserInterface
    {
        $username = $this->userIdMap[$userId] ?? null;
        if (!$username) {
            throw new UserNotFoundException();
        }
        return $this->users[$username];
    }

    /**
     * {@inheritDoc}
     *
     * @param string $username
     * @return UserInterface
     * @throws UserNotFoundException if the user can not be found
     * @throws InvalidCredentialsException if the credentials are invalid
     */
    public function getUserByUsername(string $username): UserInterface
    {
        $user = $this->users[$username] ?? null;
        if (!$user) {
            throw new UserNotFoundException();
        }
        return $user;
    }

    /**
     * {@inheritDoc}
     *
     * @param string $token
     * @return UserInterface
     * @throws UserNotFoundException if the user can not be found
     * @throws InvalidCredentialsException if the credentials are invalid
     */
    public function getUserByToken(string $token): UserInterface
    {
        foreach ($this->users as $user) {
            $userTokens = $user->getTokens();
            if (in_array($token, $userTokens))
                return $user;
        }
        throw new UserNotFoundException();
    }

}

